@@ -7,42 +7,9 @@ mode_class <- function(x) NNS.mode(x, discrete = TRUE, multi = FALSE)
 
 
 ### Gravity of a distribution
-gravity <- function(x, discrete = FALSE){
-  l <- length(x)
-  if(l <= 3) return(median(x))
-  if(length(unique(x))==1) return(x[1])
-  x_s <- x[order(x)]
-  range <- abs(x_s[l]-x_s[1])
+gravity <- function(x) NNS.gravity(x, discrete = FALSE)
 
-  if(range == 0) return(x[1])
-  
-  q1 <- sum(x_s[floor(l*.25)]+((l*.25)%%1 * (x_s[ceiling(l*.25)] - x_s[floor(l*.25)])))
-  q2 <- (x_s[floor(l*.5)]+x_s[ceiling(l*.5)])/2
-  q3 <- sum(x_s[floor(l*.75)]+((l*.75)%%1 * (x_s[ceiling(l*.75)] - x_s[floor(l*.75)])))
-
-  z <- MESS::bin(x_s, range/128, origin = x_s[1], missinglast = FALSE)
-  lz <- length(z$counts)
-  max_z <- z$counts==max(z$counts)
-  
-  if(sum(max_z)>1){
-    z_ind <- 1:lz
-  } else {
-    z_c <- which.max(z$counts)
-    z_ind <- max(1, (z_c - 1)):min(lz,(z_c + 1))
-  }
-
-  z_names <- seq(x_s[1], x_s[l], z$width)
-
-  m <- sum(z_names[z_ind] * z$counts[z_ind] )/sum(z$counts[z_ind])
-  mu <- sum(x)/l
-  
-  res <- (q2 + m + mu + mean(c(q1, q2, q3)))/4
-  if(is.na(res)) final <- q2 else final <- res
-  if(discrete) return(ifelse(final%%1 < .5, floor(final), ceiling(final))) else return(final)
-} 
-
-
-gravity_class <- function(x) gravity(x, discrete = TRUE)
+gravity_class <- function(x) NNS.gravity(x, discrete = TRUE)
 
 
 ### Factor to dummy variable
@@ -73,9 +40,8 @@ factor_2_dummy_FR <- function(x){
 
 ### Generator for 1:length(lag) vectors in NNS.ARMA
 generate.vectors <- function(x, l){
-  Component.series <- list()
-  Component.index <- list()
-
+  Component.index <- Component.series <- list()
+ 
   for (i in 1:length(l)){
     CS <- rev(x[seq(length(x)+1, 1, -l[i])])
     CS <- CS[!is.na(CS)]
@@ -126,53 +92,52 @@ ARMA.seas.weighting <- function(sf,mat){
 ### List of tau vectors for multiple different tau per variables tau = list(c(1,2,3), c(4,5,6))
 lag.mtx <- function(x, tau){
   colheads <- NULL
-
+  
   max_tau <- max(unlist(tau))
-
+  
   if(is.null(dim(x)[2])) {
     colheads <- noquote(as.character(deparse(substitute(x))))
     x <- t(t(x))
   }
-
-  j.vectors <- list()
-
+  
+  j.vectors <- vector(mode = "list", ncol(x))
+  
   for(j in 1:ncol(x)){
     if(is.null(colheads)){
       colheads <- colnames(x)[j]
-
+      
       colheads <- noquote(as.character(deparse(substitute(colheads))))
     }
-
-    x.vectors <- list()
+    
+    x.vectors <- vector(mode = "list")
     heads <- paste0(colheads, "_tau_")
     heads <- gsub('"', '' ,heads)
-
+    
     for (i in 0:max_tau){
       x.vectors[[paste(heads, i, sep = "")]] <- numeric(0L)
       start <- max_tau - i + 1
       end <- length(x[,j]) - i
       x.vectors[[i + 1]] <- x[start : end, j]
     }
-
+    
     j.vectors[[j]] <- do.call(cbind, x.vectors)
     colheads <- NULL
   }
   mtx <- as.data.frame(do.call(cbind, j.vectors))
+  
 
-  relevant_lags <- list(length(tau))
   if(length(unlist(tau)) > 1){
-    for(i in 1:(length(tau))){
-        relevant_lags[[i]] <- c((i-1)*max_tau + i, (i-1)*max_tau + unlist(tau[[i]]) + i)
-    }
+    relevant_lags <- lapply(1:length(tau), function(i) c((i-1)*max_tau + i, (i-1)*max_tau + unlist(tau[[i]]) + i))
 
     relevant_lags <- sort(unlist(relevant_lags))
     mtx <- mtx[ , relevant_lags]
   }
+  
   vars <- which(grepl("tau_0", colnames(mtx)))
-
+  
   everything_else <- seq_len(dim(mtx)[2])[-vars]
   mtx <- mtx[,c(vars, everything_else)]
-
+  
   return(mtx)
 }
 
